;; Generated package description from nano-modeline.el  -*- no-byte-compile: t -*-
(define-package "nano-modeline" "1.0.1.0.20240120.114819" "N Λ N O modeline" '((emacs "27.1")) :commit "2b0f03205c5c818a3a0622fd39779bec43dd5869" :maintainer '("Nicolas P. Rougier" . "Nicolas.Rougier@inria.fr") :keywords '("convenience" "mode-line" "header-line") :url "https://github.com/rougier/nano-modeline")
